Re: [PATCH v2] Document pack v4 format
- From
Duy Nguyen <pclouds@gmail.com>
- Date
- Sep 3, 2013, 11:49 UTC
- Message-ID
- <CACsJy8CZP+55nhfEbgRGa9=y0PyExyHt_seiSc23kB31-_c1Hg@mail.gmail.com>
- In-Reply-To
- <alpine.LFD.2.03.1309030231350.14472@syhkavp.arg>
On Tue, Sep 3, 2013 at 1:46 PM, Nicolas Pitre <nico@fluxnic.net> wrote:
Show 6 quoted lines
> So... looks like pack v4 is now "functional". > > However something is still wrong as it operates about 6 times slower > than pack v3. > > Anyone wishes to investigate?
You recurse in decode_entries too deep.I check the first 10000 decode_entries() calls in pv4_get_tree(). The deepest level is 3491.
-- Duy